package hiasm.hiasmproject;

import android.content.Context;
import android.content.Intent;
import android.location.LocationManager;
import android.location.Location;
import android.location.LocationListener;
import android.os.Bundle;
import android.os.Looper;


public class GPSListener implements LocationListener {
  
    private boolean started;
    private int mSatCount;
    private LocationManager mLocMgr;
    private Location mLoc;
    private GPSListener mThisListener;
    private Context mCont;
    
    public void init(Context cont, GPSListener listener) {
      mCont = cont;
      mLocMgr = (LocationManager) mCont.getSystemService(Context.LOCATION_SERVICE);
      mThisListener = listener;
      mLoc = new Location(LocationManager.GPS_PROVIDER);
    }
    
    public void start(long minTime, float minDistance) {
        if(started) return;
        mLocMgr.requestLocationUpdates(LocationManager.GPS_PROVIDER, minTime, minDistance, mThisListener, Looper.getMainLooper());
        started = true;
    }
    
    public void stop() {
        if(!started) return;
        mLocMgr.removeUpdates(mThisListener);
        started = false;
    }

    public double getLatitude() {
      return mLoc.getLatitude();
    }
    
    public double getLongitude() {
      return mLoc.getLongitude();
    }
    
    public long getTimeUTC() {
      return mLoc.getTime();
    }
    
    public float getAccuracy() {
      return mLoc.getAccuracy();
    }
    
    public int getSatelitesCount() {
      Bundle b = mLoc.getExtras();
      if(b != null) mSatCount = b.getInt("satellites", 0);
      return mSatCount;
    }
    
    public float getSpeed() {
      return mLoc.getSpeed();
    }
    
    @Override
    public void onLocationChanged(Location location) {
      mLoc.set(location);
      onLocationChanged();
    }

    public void onLocationChanged() {
    }
    
    @Override
    public void onProviderEnabled(String provider) {
    }

    @Override
    public void onProviderDisabled(String provider) {
    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle extras) {
    }
  
}